/* xkeycaps, Copyright (c) 1991, 1992, 1993 Jamie Zawinski <jwz@netscape.com>
 *
 * This file describes the keycodes of the SGI Iris keyboard
 * with IRIX 4.* or older.  By Simon Leinen <simon@lia.di.epfl.ch>
 */

static const KeyCode sgi4_codes [] = {

  /* Row 0 */
  14,
  94, 95, 96, 97,
  98, 99, 100, 101,
  102, 103, 104, 105,
  106, 107, 108,

  /* Row 2 */
  62, 15, 21, 22, 29, 30, 37, 38, 45, 46, 53, 54, 61, 68,
  109, 110, 111,
  114, 115, 116, 83,

  /* Row 3 */
  16, 17, 23, 24, 31, 32, 39, 40, 47, 48, 55, 56, 63, 64,
  69, 112, 113,
  74, 75, 82, 117,
  
  /* Row 4 */
  11, 18, 19, 25, 26, 33, 34, 41, 42, 49, 50, 57, 58,
  70, 76, 77,

  /* Row 5 */
  13, 27, 28, 35, 36, 43, 44, 51, 52, 59, 60, 12,
  88,
  65, 71, 72, 89,

  /* Row 6 */
  10,
  91, 90, 92,
  93,
  80, 81, 87,
  66, 73
};
